# Python 3.7

import numpy as np
import matplotlib.pyplot as plt
from numpy import sqrt

# on entre le volume équivalent et le volume de réactif titré apportés en mL, la concentration en acide Ca ainsi que les précisions associées
V_eq = 17.8
Va = 20
Ca = 0.05013
delta_V_eq = sqrt(0.10**2+0.05**2)    # on considère une précision de deux gouttes et on tient compte de la tolérance de la burette
delta_Va = 0.03
delta_Ca = 0.00018

# on entre le nombre de simulations que l'on veut effectuer
N = 10000

# calculs de Cb et de son incertitude avec une distribution de probabilité uniforme
Ca_al = np.random.uniform(Ca-delta_Ca,Ca+delta_Ca,N)
V_eq_al = np.random.uniform(V_eq-delta_V_eq,V_eq+delta_V_eq,N)
Va_al = np.random.uniform(Va-delta_Va,Va+delta_Va,N)
Cb = 2*Ca_al*Va_al/V_eq_al

plt.hist(Cb,bins='rice')
plt.show()

# Calcul et affichage moyenne et écart-type

Cb_moy = np.mean(Cb)
u_Cb = np.std(Cb,ddof=1)

print("Cb moyen vaut {:.5f} mol/L".format(Cb_moy))
print("L'écart-type sur Cb moyen vaut {:.5f} mol/L".format(u_Cb))

# Détermination de Cb et de l'incertitude-type sur Cb par composition à partir des incertitudes relatives
Cb_bis = 2*Ca*Va/V_eq
u_Ca = delta_Ca/sqrt(3)
u_Va = delta_Va/sqrt(3)
u_V_eq = delta_V_eq/sqrt(3)
u_Cb_bis = Cb_bis*sqrt((u_Va/Va)**2+(u_Ca/Ca)**2+(u_V_eq/V_eq)**2)

print("Cb vaut {:.5f} mol/L".format(Cb_bis))
print("L'incertitude-type sur Cb par propagation vaut {:.5f} mol/L".format(u_Cb_bis))




